@@ -7,9 +7,11 @@ import qualified GI.GObject.Config as GObject
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "Gio"
         version = "2.0"
+        pkgName = "gi-gio"
+        pkgVersion = "2.0.29"
         overridesFile = Just "Gio.overrides"
         verbose = False
         outputDir = Nothing
